diff --git a/src/FACT_road.jl b/src/FACT_road.jl
index 9e6e42b3e69dee591c69c2b244ab41c7268e0f1c..b5f48926809e121e4912e1d7306411f050dca44d 100644
--- a/src/FACT_road.jl
+++ b/src/FACT_road.jl
@@ -63,7 +63,7 @@ function travel_time_in_minutes(ws_host_port::String, selection::Dict)
                 travel_time = travel_time_seconds / 60
             catch e
                 println("Error during HTTP request or response parsing: ", e)
-                travel_time = nothing  # Use `nothing` to represent null in Julia
+                travel_time = missing  # Use `missing` to represent null in Julia
             end
 
             # Populate the columns